==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/structfsdk_1_1_i_face_engine.js <==
var structfsdk_1_1_i_face_engine =
[
    [ "createAGSEstimator", "structfsdk_1_1_i_face_engine.html#a834591987b03c33c2ff1da5e5990e9af", null ],
    [ "createAsyncContext", "structfsdk_1_1_i_face_engine.html#a20c1425be4a4dd129aa0479f3afb841a", null ],
    [ "createAttributeEstimator", "structfsdk_1_1_i_face_engine.html#abe99c8e892ed6d9af69d042764f19f09", null ],
    [ "createBackgroundEstimator", "structfsdk_1_1_i_face_engine.html#a376b938eb62749d618c3a80c20993bfc", null ],
    [ "createBestShotQualityEstimator", "structfsdk_1_1_i_face_engine.html#a2075f8c79bba307c4bb675dfa1d5adf5", null ],
    [ "createBlackWhiteEstimator", "structfsdk_1_1_i_face_engine.html#a9d17a04bd4e59ef97b899285db26c648", null ],
    [ "createCredibilityCheckEstimator", "structfsdk_1_1_i_face_engine.html#ad141931e31e89496784bb0ea09b49e79", null ],
    [ "createCrowdEstimator", "structfsdk_1_1_i_face_engine.html#ae99a28d46da541bb1f7917e8af1adc87", null ],
    [ "createDeepFakeEstimator", "structfsdk_1_1_i_face_engine.html#a0aba9ee4bbbb7cddda845abf1799d76a", null ],
    [ "createDepthEstimator", "structfsdk_1_1_i_face_engine.html#a7df66bedc8da1c49029f2ccf07576317", null ],
    [ "createDepthLivenessEstimator", "structfsdk_1_1_i_face_engine.html#abdbe4b0c5249837b0b4aaa4534b26fc9", null ],
    [ "createDescriptor", "structfsdk_1_1_i_face_engine.html#a8ab08ec06d174a96d77b340f637b1042", null ],
    [ "createDescriptor", "structfsdk_1_1_i_face_engine.html#aa78c0606e4d6a03b8324d90534d45a50", null ],
    [ "createDescriptorBatch", "structfsdk_1_1_i_face_engine.html#a55a6644234385910932c666bf803d901", null ],
    [ "createDetector", "structfsdk_1_1_i_face_engine.html#ae6579925a85ece4e83e66b962d586458", null ],
    [ "createDynamicRangeEstimator", "structfsdk_1_1_i_face_engine.html#a455bf5951c97f27dea13815b6803a8c6", null ],
    [ "createEmotionsEstimator", "structfsdk_1_1_i_face_engine.html#a4e8c4042596a2482dbfca569f995c315", null ],
    [ "createEthnicityEstimator", "structfsdk_1_1_i_face_engine.html#ae6c56e131e32e091efb9dc4d3ff52182", null ],
    [ "createExtractor", "structfsdk_1_1_i_face_engine.html#adbd6041724826b29dc1720aef8a9f708", null ],
    [ "createEyeBrowEstimator", "structfsdk_1_1_i_face_engine.html#af68a39f42764736a7c0eb5779e709236", null ],
    [ "createEyeEstimator", "structfsdk_1_1_i_face_engine.html#a52dba778ec232817be3cb8f36c08fdfd", null ],
    [ "createFaceLandmarksDetector", "structfsdk_1_1_i_face_engine.html#a17b8a24d1a18e77a6a5f2ee7775a0c27", null ],
    [ "createFaceOcclusionEstimator", "structfsdk_1_1_i_face_engine.html#a907741fecc658a908bbb7a78d86eed1c", null ],
    [ "createFacialHairEstimator", "structfsdk_1_1_i_face_engine.html#adb2d81c2db81a92ab36e3d307a75dd2d", null ],
    [ "createFightsEstimator", "structfsdk_1_1_i_face_engine.html#af2acafc6d31b27dd0f23f96a2bb2dae5", null ],
    [ "createFishEyeEstimator", "structfsdk_1_1_i_face_engine.html#a2c37382df6c83e3877cafe299f944733", null ],
    [ "createGazeEstimator", "structfsdk_1_1_i_face_engine.html#ab6c34dfe51646fc93ed079757037b0e8", null ],
    [ "createGlassesEstimator", "structfsdk_1_1_i_face_engine.html#abfb354583f186c7f8347550ccfd43f9d", null ],
    [ "createHeadDetector", "structfsdk_1_1_i_face_engine.html#ac8f99da60b9cc16ccd7a83b4e33a9ae1", null ],
    [ "createHeadPoseEstimator", "structfsdk_1_1_i_face_engine.html#aeaf545945911a9b111c34ba94b186ec5", null ],
    [ "createHeadWearEstimator", "structfsdk_1_1_i_face_engine.html#a0ba45ce7fed4c35e8486d0c40e6df89f", null ],
    [ "createHumanAttributeEstimator", "structfsdk_1_1_i_face_engine.html#a4d6ddc295c9c0464da58b2af2bf94413", null ],
    [ "createHumanDetector", "structfsdk_1_1_i_face_engine.html#a15d24a9bc040b211cd69604783ac9304", null ],
    [ "createHumanFaceDetector", "structfsdk_1_1_i_face_engine.html#a543eaccde37fc171f4d7796d4776498f", null ],
    [ "createHumanWarper", "structfsdk_1_1_i_face_engine.html#a9a6844a3e131a867e30ced7a33fccc73", null ],
    [ "createImageModificationEstimator", "structfsdk_1_1_i_face_engine.html#a53e1b6d6720ec4e2ec0f0aa3ea0115f2", null ],
    [ "createImageTransfer", "structfsdk_1_1_i_face_engine.html#a75bd39636f4b25903af0dfeee1b43f09", null ],
    [ "createIndexBuilder", "structfsdk_1_1_i_face_engine.html#a046c870070ad6a0b1a92a53f677f4650", null ],
    [ "createIREstimator", "structfsdk_1_1_i_face_engine.html#a49a39e1e4e4d6285479f70cde51cc34c", null ],
    [ "createLivenessDepthRGBEstimator", "structfsdk_1_1_i_face_engine.html#a63373ec0f6edef6ea35fa1390daeb1f4", null ],
    [ "createLivenessFlyingFacesEstimator", "structfsdk_1_1_i_face_engine.html#a30bea4c0c6b00c3a07b456f3f73e14cc", null ],
    [ "createLivenessFPREstimator", "structfsdk_1_1_i_face_engine.html#a158131b08efb00bdb6fe49048a8491ba", null ],
    [ "createLivenessOneShotRGBEstimator", "structfsdk_1_1_i_face_engine.html#add9210795406f2a190c0eeae96c1a206", null ],
    [ "createLivenessRGBMEstimator", "structfsdk_1_1_i_face_engine.html#aa68a2b853e78654451b03bc5e6677183", null ],
    [ "createMatcher", "structfsdk_1_1_i_face_engine.html#add818615812283e114b2ec1bdec145ed", null ],
    [ "createMedicalMaskEstimator", "structfsdk_1_1_i_face_engine.html#aad1bbfd02e86750247aaf0ffaf82744f", null ],
    [ "createMouthEstimator", "structfsdk_1_1_i_face_engine.html#a2f9745396b84c65569809251c1ac3b11", null ],
    [ "createNaturalLightEstimator", "structfsdk_1_1_i_face_engine.html#a1f1ce28be4d5e5e64163ededcfa2e691", null ],
    [ "createNIRLivenessEstimator", "structfsdk_1_1_i_face_engine.html#a22f78667879d73f6c04b87d509084c14", null ],
    [ "createOrientationEstimator", "structfsdk_1_1_i_face_engine.html#a7f981126eb4e8c95983b0dbe1110d2d8", null ],
    [ "createOverlapEstimator", "structfsdk_1_1_i_face_engine.html#afb8e25cb01d9a732dc3c12a3410e4e1a", null ],
    [ "createPortraitStyleEstimator", "structfsdk_1_1_i_face_engine.html#a0ec8a4ec31727530d80e192b792282bd", null ],
    [ "createPPEEstimator", "structfsdk_1_1_i_face_engine.html#a7b3e36dec1d8b50b839a1e58a20f7516", null ],
    [ "createQualityEstimator", "structfsdk_1_1_i_face_engine.html#a93eaa1b7aee31053da844d02950469b2", null ],
    [ "createRedEyeEstimator", "structfsdk_1_1_i_face_engine.html#a97e66ca0508ec6c7ca1b7e30c34ad5f5", null ],
    [ "createWarper", "structfsdk_1_1_i_face_engine.html#aa7a8c38b1d15c000080e4523600bba33", null ],
    [ "getDataDirectory", "structfsdk_1_1_i_face_engine.html#a6fa75906d8426d77c879a844efee50e2", null ],
    [ "getFaceEngineEdition", "structfsdk_1_1_i_face_engine.html#aaa0024131e31ab3b9302325a78955d2e", null ],
    [ "getLicense", "structfsdk_1_1_i_face_engine.html#a24dc72f7ab618cf5ad35bb5159296cd4", null ],
    [ "getRuntimeSettingsProvider", "structfsdk_1_1_i_face_engine.html#aa5b98bb31004abf71309327932798d40", null ],
    [ "getSettingsProvider", "structfsdk_1_1_i_face_engine.html#abf826d30179505d9a08854960338f9aa", null ],
    [ "loadDenseIndex", "structfsdk_1_1_i_face_engine.html#a3ab93bb755da63391c9baf276e308313", null ],
    [ "loadDynamicIndex", "structfsdk_1_1_i_face_engine.html#aa37f7db7f77a4543224496ad7a1dd798", null ],
    [ "setDataDirectory", "structfsdk_1_1_i_face_engine.html#a58eb8660079affaa0d3e9b684e751479", null ],
    [ "setRuntimeSettingsProvider", "structfsdk_1_1_i_face_engine.html#ae7e6ca6f139b0bd46581cf98c265ea5e", null ],
    [ "setSettingsProvider", "structfsdk_1_1_i_face_engine.html#af379531b6060c674591c722b3b71a6c2", null ]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/structfsdk_1_1_i_face_engine.js <==
var structfsdk_1_1_i_face_engine =
[
    [ "createAGSEstimator", "structfsdk_1_1_i_face_engine.html#a834591987b03c33c2ff1da5e5990e9af", null ],
    [ "createAsyncContext", "structfsdk_1_1_i_face_engine.html#a20c1425be4a4dd129aa0479f3afb841a", null ],
    [ "createAttributeEstimator", "structfsdk_1_1_i_face_engine.html#abe99c8e892ed6d9af69d042764f19f09", null ],
    [ "createBackgroundEstimator", "structfsdk_1_1_i_face_engine.html#a376b938eb62749d618c3a80c20993bfc", null ],
    [ "createBestShotQualityEstimator", "structfsdk_1_1_i_face_engine.html#a2075f8c79bba307c4bb675dfa1d5adf5", null ],
    [ "createBlackWhiteEstimator", "structfsdk_1_1_i_face_engine.html#a9d17a04bd4e59ef97b899285db26c648", null ],
    [ "createCredibilityCheckEstimator", "structfsdk_1_1_i_face_engine.html#ad141931e31e89496784bb0ea09b49e79", null ],
    [ "createCrowdEstimator", "structfsdk_1_1_i_face_engine.html#ae99a28d46da541bb1f7917e8af1adc87", null ],
    [ "createDeepFakeEstimator", "structfsdk_1_1_i_face_engine.html#a0aba9ee4bbbb7cddda845abf1799d76a", null ],
    [ "createDepthEstimator", "structfsdk_1_1_i_face_engine.html#a7df66bedc8da1c49029f2ccf07576317", null ],
    [ "createDepthLivenessEstimator", "structfsdk_1_1_i_face_engine.html#abdbe4b0c5249837b0b4aaa4534b26fc9", null ],
    [ "createDescriptor", "structfsdk_1_1_i_face_engine.html#a8ab08ec06d174a96d77b340f637b1042", null ],
    [ "createDescriptor", "structfsdk_1_1_i_face_engine.html#aa78c0606e4d6a03b8324d90534d45a50", null ],
    [ "createDescriptorBatch", "structfsdk_1_1_i_face_engine.html#a55a6644234385910932c666bf803d901", null ],
    [ "createDetector", "structfsdk_1_1_i_face_engine.html#ae6579925a85ece4e83e66b962d586458", null ],
    [ "createDynamicRangeEstimator", "structfsdk_1_1_i_face_engine.html#a455bf5951c97f27dea13815b6803a8c6", null ],
    [ "createEmotionsEstimator", "structfsdk_1_1_i_face_engine.html#a4e8c4042596a2482dbfca569f995c315", null ],
    [ "createEthnicityEstimator", "structfsdk_1_1_i_face_engine.html#ae6c56e131e32e091efb9dc4d3ff52182", null ],
    [ "createExtractor", "structfsdk_1_1_i_face_engine.html#adbd6041724826b29dc1720aef8a9f708", null ],
    [ "createEyeBrowEstimator", "structfsdk_1_1_i_face_engine.html#af68a39f42764736a7c0eb5779e709236", null ],
    [ "createEyeEstimator", "structfsdk_1_1_i_face_engine.html#a52dba778ec232817be3cb8f36c08fdfd", null ],
    [ "createFaceLandmarksDetector", "structfsdk_1_1_i_face_engine.html#a17b8a24d1a18e77a6a5f2ee7775a0c27", null ],
    [ "createFaceOcclusionEstimator", "structfsdk_1_1_i_face_engine.html#a907741fecc658a908bbb7a78d86eed1c", null ],
    [ "createFacialHairEstimator", "structfsdk_1_1_i_face_engine.html#adb2d81c2db81a92ab36e3d307a75dd2d", null ],
    [ "createFightsEstimator", "structfsdk_1_1_i_face_engine.html#af2acafc6d31b27dd0f23f96a2bb2dae5", null ],
    [ "createFishEyeEstimator", "structfsdk_1_1_i_face_engine.html#a2c37382df6c83e3877cafe299f944733", null ],
    [ "createGazeEstimator", "structfsdk_1_1_i_face_engine.html#ab6c34dfe51646fc93ed079757037b0e8", null ],
    [ "createGlassesEstimator", "structfsdk_1_1_i_face_engine.html#abfb354583f186c7f8347550ccfd43f9d", null ],
    [ "createHeadDetector", "structfsdk_1_1_i_face_engine.html#ac8f99da60b9cc16ccd7a83b4e33a9ae1", null ],
    [ "createHeadPoseEstimator", "structfsdk_1_1_i_face_engine.html#aeaf545945911a9b111c34ba94b186ec5", null ],
    [ "createHeadWearEstimator", "structfsdk_1_1_i_face_engine.html#a0ba45ce7fed4c35e8486d0c40e6df89f", null ],
    [ "createHumanAttributeEstimator", "structfsdk_1_1_i_face_engine.html#a4d6ddc295c9c0464da58b2af2bf94413", null ],
    [ "createHumanDetector", "structfsdk_1_1_i_face_engine.html#a15d24a9bc040b211cd69604783ac9304", null ],
    [ "createHumanFaceDetector", "structfsdk_1_1_i_face_engine.html#a543eaccde37fc171f4d7796d4776498f", null ],
    [ "createHumanWarper", "structfsdk_1_1_i_face_engine.html#a9a6844a3e131a867e30ced7a33fccc73", null ],
    [ "createImageModificationEstimator", "structfsdk_1_1_i_face_engine.html#a53e1b6d6720ec4e2ec0f0aa3ea0115f2", null ],
    [ "createImageTransfer", "structfsdk_1_1_i_face_engine.html#a75bd39636f4b25903af0dfeee1b43f09", null ],
    [ "createIndexBuilder", "structfsdk_1_1_i_face_engine.html#a046c870070ad6a0b1a92a53f677f4650", null ],
    [ "createLivenessDepthRGBEstimator", "structfsdk_1_1_i_face_engine.html#a63373ec0f6edef6ea35fa1390daeb1f4", null ],
    [ "createLivenessFlyingFacesEstimator", "structfsdk_1_1_i_face_engine.html#a30bea4c0c6b00c3a07b456f3f73e14cc", null ],
    [ "createLivenessOneShotRGBEstimator", "structfsdk_1_1_i_face_engine.html#add9210795406f2a190c0eeae96c1a206", null ],
    [ "createLivenessRGBMEstimator", "structfsdk_1_1_i_face_engine.html#aa68a2b853e78654451b03bc5e6677183", null ],
    [ "createMatcher", "structfsdk_1_1_i_face_engine.html#add818615812283e114b2ec1bdec145ed", null ],
    [ "createMedicalMaskEstimator", "structfsdk_1_1_i_face_engine.html#aad1bbfd02e86750247aaf0ffaf82744f", null ],
    [ "createMouthEstimator", "structfsdk_1_1_i_face_engine.html#a2f9745396b84c65569809251c1ac3b11", null ],
    [ "createNaturalLightEstimator", "structfsdk_1_1_i_face_engine.html#a1f1ce28be4d5e5e64163ededcfa2e691", null ],
    [ "createNIRLivenessEstimator", "structfsdk_1_1_i_face_engine.html#a22f78667879d73f6c04b87d509084c14", null ],
    [ "createOrientationEstimator", "structfsdk_1_1_i_face_engine.html#a7f981126eb4e8c95983b0dbe1110d2d8", null ],
    [ "createOverlapEstimator", "structfsdk_1_1_i_face_engine.html#afb8e25cb01d9a732dc3c12a3410e4e1a", null ],
    [ "createPortraitStyleEstimator", "structfsdk_1_1_i_face_engine.html#a0ec8a4ec31727530d80e192b792282bd", null ],
    [ "createPPEEstimator", "structfsdk_1_1_i_face_engine.html#a7b3e36dec1d8b50b839a1e58a20f7516", null ],
    [ "createQualityEstimator", "structfsdk_1_1_i_face_engine.html#abaab04505fa2647f8e75b27bc46c29bf", null ],
    [ "createRedEyeEstimator", "structfsdk_1_1_i_face_engine.html#a97e66ca0508ec6c7ca1b7e30c34ad5f5", null ],
    [ "createSubjectiveQualityEstimator", "structfsdk_1_1_i_face_engine.html#aaa2a1556332cf8b6d9a3ba48da4ab625", null ],
    [ "createWarper", "structfsdk_1_1_i_face_engine.html#aa7a8c38b1d15c000080e4523600bba33", null ],
    [ "FSDK_DEPRECATED", "structfsdk_1_1_i_face_engine.html#a76b2da4f1fd8c27d7b950f8564623513", null ],
    [ "getDataDirectory", "structfsdk_1_1_i_face_engine.html#a6fa75906d8426d77c879a844efee50e2", null ],
    [ "getFaceEngineEdition", "structfsdk_1_1_i_face_engine.html#aaa0024131e31ab3b9302325a78955d2e", null ],
    [ "getLicense", "structfsdk_1_1_i_face_engine.html#a24dc72f7ab618cf5ad35bb5159296cd4", null ],
    [ "getRuntimeSettingsProvider", "structfsdk_1_1_i_face_engine.html#aa5b98bb31004abf71309327932798d40", null ],
    [ "getSettingsProvider", "structfsdk_1_1_i_face_engine.html#abf826d30179505d9a08854960338f9aa", null ],
    [ "loadDenseIndex", "structfsdk_1_1_i_face_engine.html#a3ab93bb755da63391c9baf276e308313", null ],
    [ "loadDynamicIndex", "structfsdk_1_1_i_face_engine.html#aa37f7db7f77a4543224496ad7a1dd798", null ],
    [ "setDataDirectory", "structfsdk_1_1_i_face_engine.html#a58eb8660079affaa0d3e9b684e751479", null ],
    [ "setRuntimeSettingsProvider", "structfsdk_1_1_i_face_engine.html#ae7e6ca6f139b0bd46581cf98c265ea5e", null ],
    [ "setSettingsProvider", "structfsdk_1_1_i_face_engine.html#af379531b6060c674591c722b3b71a6c2", null ]
];
